package com.ruoyi.mall.mapper;

import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * 首页数据Mapper
 */
public interface IndexDataMapper {

    /**
     * 今日成交额
     * @return
     */
    public BigDecimal selectTodayPrice(@Param("shopId")Long shopId);

    /**
     * 今日总访客
     * @return
     */
    public Integer selectTodayVisitCount();

    /**
     * 今日订单数
     * @return
     */
    public Integer selectTodayOrderCount(@Param("shopId")Long shopId);

    /**
     * 近七天日期
     * @return
     */
    public List<String> oneWeekDate();

    /**
     * 近七天成交额
     * @return
     */
    public List<BigDecimal> oneWeekPrice(@Param("shopId")Long shopId);

    /**
     * 近七天访客
     * @return
     */
    public List<Integer> oneWeekVisitCount();

    /**
     * 近七天订单数
     * @return
     */
    public List<Integer> oneWeekOrderCount(@Param("shopId")Long shopId);


}
